==> apache-streampipes-0.68.0-incubating-source-release.zip: apache-streampipes-0.68.0-incubating/streampipes-rest/src/main/java/org/apache/streampipes/rest/impl/PipelineMonitoring.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.rest.impl;

import org.apache.streampipes.manager.monitoring.pipeline.PipelineExecutionStatusCollector;
import org.apache.streampipes.rest.api.IPipelineMonitoring;
import org.apache.streampipes.rest.shared.annotation.JacksonSerialized;

import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

@Path("/v2/users/{username}/pipeline-monitoring")
public class PipelineMonitoring extends AbstractRestResource implements IPipelineMonitoring {

  @JacksonSerialized
  @Path("{pipelineId}")
  @GET
  @Produces(MediaType.APPLICATION_JSON)
  @Override
  public Response getPipelineMonitoringInfo(@PathParam("pipelineId") String pipelineId) {
    return ok(new PipelineExecutionStatusCollector(pipelineId).makePipelineMonitoringInfo());
  }
}

==> apache-streampipes-0.70.0-incubating-source-release.zip: apache-streampipes-0.70.0-incubating/streampipes-rest/src/main/java/org/apache/streampipes/rest/impl/PipelineMonitoring.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.rest.impl;

import org.apache.streampipes.manager.monitoring.pipeline.PipelineExecutionStatusCollector;
import org.apache.streampipes.rest.api.IPipelineMonitoring;
import org.apache.streampipes.rest.core.base.impl.AbstractRestResource;
import org.apache.streampipes.rest.shared.annotation.JacksonSerialized;

import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

@Path("/v2/pipeline-monitoring")
public class PipelineMonitoring extends AbstractRestResource implements IPipelineMonitoring {

  @JacksonSerialized
  @Path("{pipelineId}")
  @GET
  @Produces(MediaType.APPLICATION_JSON)
  @Override
  public Response getPipelineMonitoringInfo(@PathParam("pipelineId") String pipelineId) {
    return ok(new PipelineExecutionStatusCollector(pipelineId).makePipelineMonitoringInfo());
  }
}
